@@ -1,3 +1,4 @@
+
 /**********************************************************************
  * file: compgenepred.cc licence: Artistic Licence, see file
  * LICENCE.TXT or
@@ -23,6 +24,7 @@
 #include "contTimeMC.hh"
 #include "liftover.hh"
 #include "intronmodel.hh"
+#include "train_logReg_param.hh"
 
 #include <gsl/gsl_matrix.h>
 #include <ctime>
@@ -31,6 +33,7 @@
 
 CompGenePred::CompGenePred() : tree(Constant::treefile) {
 
+    rsa = NULL;
     vector<string> speciesNames;
     tree.getSpeciesNames(speciesNames);
     cout<<"-------Speciesnames:--------"<<endl;
@@ -38,6 +41,11 @@ CompGenePred::CompGenePred() : tree(Constant::treefile) {
       cout<<"species "<<j<<"\t"<<speciesNames[j]<<endl;
     }
 
+    if (Properties::hasProperty("trainFeatureFile")) {
+      trainFeature_from_file();
+      train_OEscore_params(speciesNames.size());
+    } else {
+
     if (Constant::Constant::dbaccess.empty()) { // give priority to database in case both exist
         rsa = new MemSeqAccess(speciesNames);
     } else {
@@ -70,10 +78,16 @@ CompGenePred::CompGenePred() : tree(Constant::treefile) {
         --dbaccess=dbname.db\n");
 	}
     }
+    }
 }
 
 void CompGenePred::start(){
 
+
+  // check if training mode is turned on and logreg features shall be read from file
+  
+  if(!Properties::hasProperty("trainFeatureFile")){
+
     // read in alignment, determine orthologous sequence fragments
 
     int num_phylo_states; // number of states in ExonEvo model
@@ -93,6 +107,8 @@ void CompGenePred::start(){
     OrthoGraph::tree = &tree;
     GeneMSA::setTree(&tree);
     OrthoGraph::numSpecies = OrthoGraph::tree->numSpecies();
+    vector<string> speciesNames;
+    OrthoGraph::tree->getSpeciesNames(speciesNames);    
     Boolean noprediction = false;
     Boolean useLocusTrees = false; // reestimate tree for each gene range
 
@@ -156,6 +172,9 @@ void CompGenePred::start(){
 	cerr << "Warning: /CompPred/rounds was set to "<<rounds<<". At least one round must be made." << endl;
 	rounds =1;
     }
+    const char* dd_step_rule = Properties::hasProperty("/CompPred/dd_step_rule") ? Properties::getProperty("/CompPred/dd_step_rule") : "mixed";
+    OrthoGraph::setStepRule(dd_step_rule);
+    
     string dd_param_s; 
     // parameter that defines the step size in dual decomposition.
     // If a range is given, all values in that range are tried until convergence is achieved
@@ -163,8 +182,10 @@ void CompGenePred::start(){
     try {
         dd_param_s = Properties::getProperty("/CompPred/dd_factor");
     } catch (...) {
-        dd_param_s = "1-5"; // default, do 5 rounds with parameters 1,2,3,4,5
+        dd_param_s = "1-4"; // default: 1st round "polyak", 2nd-5th round "square_root" with c=1,2,3,4
     }
+    if(OrthoGraph::step_rule == polyak) // only one round possible for this step size rule
+	dd_param_s = "1";
     try{
 	size_t i = dd_param_s.find('-');
 	if(i != std::string::npos){
@@ -176,9 +197,15 @@ void CompGenePred::start(){
 		throw ProjectError("Cannot read interval end.");
 	    if(start > end)
 		throw ProjectError("Interval start greater than interval end.");
-	    for (int i=0; i < rounds; i++){
-		dd_factors.push_back(start+i*(end-start)/(rounds-1));
-	    }	
+	    if(OrthoGraph::step_rule == mixed){ // 1st round: polyak, 2nd round and onwards: square_root
+		dd_factors.push_back(1);        // dummy, not required in first round
+		for (int i=0; i < rounds-1; i++)
+                    dd_factors.push_back(start+i*(end-start)/(rounds-2));
+	    }
+	    else{
+		for (int i=0; i < rounds; i++)
+		    dd_factors.push_back(start+i*(end-start)/(rounds-1));	
+	    }
 	}
 	else{
 	    double pos;	    
@@ -189,13 +216,29 @@ void CompGenePred::start(){
     } catch (ProjectError e) {
 	throw ProjectError("Format error parsing parameter --/CompPred/dd_factor=" + dd_param_s +".\n" + e.getMessage());
     }
+    bool onlySampling = false;
     try {
 	noprediction = Properties::getBoolProperty("noprediction");
     } catch (...) {}
+    if(Properties::hasProperty("referenceFile")){
+      onlySampling = true;
+      cout << "# AUGUSTUS is running in training mode. No prediction will be done!" << endl;
+      try {
+	Constant::refSpecies = Properties::getProperty("refSpecies");
+	if(Properties::hasProperty("param_outfile")){
+	  cout << "# Using file " << Properties::getProperty("param_outfile") << " to store logReg parameters." << endl;
+	}else{
+	  cout << "# No outfile for logReg parameters specified. Writing parameters to " << Constant::configPath <<  "/cgp/log_reg_parameters_trained.cfg" << endl;
+	}
+      } catch (ProjectError e) {
+	throw ProjectError("For parameter training a reference species must be specified. Use --refSpecies=<SPECIES> and note, that <SPECIES> must be identical to one of the species names provided in the alignment and tree files.");
+      }
+    }
     try {
 	useLocusTrees = Properties::getBoolProperty("locustree");
     } catch (...) {}
     
+
     if(Constant::alternatives_from_evidence){
 	cerr << "Warning: The option 'alternatives-from-evidence' is only available in single species mode. Turned it off." << endl
 	     << "Rerun with --alternatives-from-evidence=0 to remove this warning." << endl;
@@ -279,7 +322,7 @@ void CompGenePred::start(){
     try{ 
       use_omega = Properties::getBoolProperty("/CompPred/omega");
     } catch (...){
-      if(Constant::logreg)
+      if(Constant::logreg && Constant::ex_sc[6] != 0)
 	use_omega = true;
       else
 	use_omega = false;
@@ -308,6 +351,13 @@ void CompGenePred::start(){
     NAMGene namgene; // creates and initializes the states
     StateModel::readAllParameters(); // read in the parameter files: species_{igenic,exon,intron,utr}_probs.pbl
 
+    int k; // number of omega values for which rate matrices are stored
+    try {
+      k = Properties::getIntProperty("/CompPred/num_omega");
+    } catch(...){
+      k = 20;
+    }
+
     // initializing codon rate matricies, for exon evolution see code above (evo)
     PhyloTree ctree(tree); // codon tree
     ctree.scaleTree(ctree_scaling_factor); // scale branch lengths to codon substitutions 
@@ -319,21 +369,19 @@ void CompGenePred::start(){
     codonevo.setPi(pi);
     codonevo.setBranchLengths(ct_branchset, 25);
     //codonevo.printBranchLengths();
-    codonevo.setOmegas(20);
+    codonevo.setOmegas(k);
     // TODO: different prior for coding and noncoding
     codonevo.setPrior(0.5);
     if(Constant::useAArates){
       codonevo.setAAPostProbs();
     }
-    /*cout << "Omegas, for which substitution matrices are stored:" << endl;
-      codonevo.printOmegas();*/
+    //cout << "Omegas, for which substitution matrices are stored:" << endl;
+    //codonevo.printOmegas();
     codonevo.computeLogPmatrices();
     
     // gsl_matrix *P = codonevo.getSubMatrixLogP(0.3, 0.25);
     // printCodonMatrix(P);
     GeneMSA::setCodonEvo(&codonevo);
-    vector<string> speciesNames;
-    OrthoGraph::tree->getSpeciesNames(speciesNames);
     GenomicMSA msa(rsa);
     msa.readAlignment(Constant::alnfile);  // reads the alignment
     // msa.printAlignment("");    
@@ -372,16 +420,16 @@ void CompGenePred::start(){
 		    list<Transcript*> *transcripts = NULL;
 
 		    if (!noprediction){
-			SequenceFeatureCollection* sfc = rsa->getFeatures(speciesNames[s],seqID,start,end,geneRange->getStrand(s));
-			sfc->prepare(as, false, rsa->withEvidence(speciesNames[s]));
-			namgene.doViterbiPiecewise(*sfc, as, bothstrands); // sampling
-			transcripts = namgene.getAllTranscripts();
-			orthograph.sfcs[s] = sfc;
-	                orthograph.ptrs_to_alltranscripts[s] = transcripts;
+		      SequenceFeatureCollection* sfc = rsa->getFeatures(speciesNames[s],seqID,start,end,geneRange->getStrand(s));
+		      sfc->prepare(as, false, rsa->withEvidence(speciesNames[s]));
+		      namgene.doViterbiPiecewise(*sfc, as, bothstrands); // sampling
+		      transcripts = namgene.getAllTranscripts();
+		      orthograph.sfcs[s] = sfc;
+		      orthograph.ptrs_to_alltranscripts[s] = transcripts;
 		    } else {
-			// turn whole sequence to lowercase characters
-			for (unsigned pos = 0; pos < as->length; pos++)
-			    as->sequence[pos] = tolower(as->sequence[pos]);
+		      // turn whole sequence to lowercase characters
+		      for (unsigned pos = 0; pos < as->length; pos++)
+			as->sequence[pos] = tolower(as->sequence[pos]);
 		    }
 		    // insert sampled exons into the EC hash
 		    if (transcripts){		    
@@ -493,7 +541,7 @@ void CompGenePred::start(){
 	if (conservation)
 	    geneRange->calcConsScore(hects, seqRanges, outdir);
 
-	if(!noprediction){
+	if(!noprediction && !onlySampling){
 	    orthograph.linkToOEs(hects); // link ECs in HECTs to nodes in orthograph	    
 	    orthograph.globalPathSearch();
 	    orthograph.outputGenes(baseGenes,base_geneid);
@@ -513,6 +561,17 @@ void CompGenePred::start(){
 	}
 	if(Constant::printOEs)
 	    geneRange->printOrthoExons(hects);
+	    
+	// store hect features globally for training
+	if(Properties::hasProperty("referenceFile")){
+	  cout << "collect sample features" << endl;
+	  int speciesID = find(speciesNames.begin(), speciesNames.end(), Constant::refSpecies) - speciesNames.begin();
+	  if(speciesID >= speciesNames.size()){
+	    throw ProjectError("Species " + Constant::refSpecies + " not found. Use one of the names specified in the alignment file as a reference!");
+	  }else{
+	    geneRange->collect_features(speciesID, &hects, orthograph.graphs[speciesID]);
+	  }
+	}
 
 	// delete sequences
 	for (int i=0; i<seqRanges.size(); i++) {
@@ -532,5 +591,11 @@ void CompGenePred::start(){
 	delete topit->second;
     }                                                                                                                                                              
     GeneMSA::topologies.clear(); 
-
+  
+    if(Properties::hasProperty("referenceFile")){
+      // initialise training of log reg parameters
+      train_OEscore_params(speciesNames.size());
+    }
+  } 
 }
+
