@@ -75,6 +75,8 @@ const char* Properties::parameternames[NUMPARNAMES]=
 "/CompPred/logreg",
 "/CompPred/maxCov",
 "/CompPred/omega",
+"/CompPred/num_omega",
+"/CompPred/num_features",
 "/CompPred/scale_codontree",
 "/CompPred/oeExtensionWidth",
 "/CompPred/onlySampledECs",
@@ -87,8 +89,10 @@ const char* Properties::parameternames[NUMPARNAMES]=
 "/CompPred/phylo_model",
 "/CompPred/dd_factor",
 "/CompPred/dd_rounds",
+"/CompPred/dd_step_rule",
 "/CompPred/dualdecomp",
 "/CompPred/overlapcomp",
+"/CompPred/lambda",
 "/Constant/almost_identical_maxdiff",
 "/Constant/amberprob",
 "/Constant/ass_end",
@@ -157,6 +161,7 @@ const char* Properties::parameternames[NUMPARNAMES]=
 "exonnames",
 EXTRFILE_KEY,
 "GCwinsize",
+"GD_stepsize",
 "/genbank/verbosity",
 "gff3",
 HINTSFILE_KEY,
@@ -187,11 +192,14 @@ HINTSFILE_KEY,
 "/IntronModel/verbosity",
 "introns",
 "keep_viterbi",
+"label_flip_prob",
+"learning_rate",
 "lossweight", // temp
 "locustree",
 "maxDNAPieceSize",
 "maxOvlp",
 "maxtracks",
+"max_sgd_inter",
 "mea",
 "mea_evaluation",
 "/MeaPrediction/no_compatible_edges",
@@ -225,6 +233,7 @@ HINTSFILE_KEY,
 EXTERNAL_KEY, // optCfgFile
 "printOEs",
 "outfile",
+"param_outfile",
 "predictionEnd",
 "predictionStart",
 "print_blocks",
@@ -242,6 +251,10 @@ EXTERNAL_KEY, // optCfgFile
 "/ProteinModel/invalid_score",
 "/ProteinModel/weight",
 "proteinprofile",
+"referenceFile",
+"refSpecies",
+"rescaleBoni",
+"rLogReg",
 "sample",
 "scorediffweight", // temp
 SINGLESTRAND_KEY,
@@ -253,6 +266,7 @@ SINGLESTRAND_KEY,
 "strand",
 "temperature",
 "tieIgenicIntron",
+"trainFeatureFile",
 "translation_table",
 "treefile",
 "truncateMaskedUTRs",
@@ -262,6 +276,8 @@ SINGLESTRAND_KEY,
 "uniqueGeneId",
 "useAminoAcidRates",
 "useNonCodingModel",
+"use_sgd",
+"useTFprob",
 UTR_KEY,
 "/UtrModel/d_polya_cleavage_max",
 "/UtrModel/d_polya_cleavage_min",
@@ -294,7 +310,7 @@ UTR_KEY,
 "/UtrModel/verbosity"};
 
 
-void Properties::readFile( string filename ) throw( PropertiesError ){
+void Properties::readFile( string filename ){
     ifstream strm;
     strm.open( filename.c_str() );
     if (!strm) {
@@ -357,7 +373,8 @@ void Properties::init( int argc, char* argv[] ){
 		name == TREE_KEY ||
 		name == DB_KEY ||
 		name == SEQ_KEY ||
-		name == CODONALN_KEY)
+		name == CODONALN_KEY ||
+		name == REF_EXON_KEY)
 	    {
 		if (pos >= argstr.length()-1)
 		    throw ProjectError(string("Wrong argument format for ") +  name + ". Use: --argument=value");
@@ -375,6 +392,7 @@ void Properties::init( int argc, char* argv[] ){
     Properties::assignProperty(SEQ_KEY, Constant::speciesfilenames);
     Properties::assignProperty(DB_KEY, Constant::dbaccess);
     Properties::assignProperty(ALN_KEY, Constant::alnfile);
+    Properties::assignProperty(REF_EXON_KEY, Constant::referenceFile);
     if(Constant::codonalnfile.empty()){
       if (!Constant::alnfile.empty() && !Constant::treefile.empty() && (!Constant::speciesfilenames.empty() || !Constant::dbaccess.empty())){
 	Constant::MultSpeciesMode = true;
@@ -411,7 +429,7 @@ void Properties::init( int argc, char* argv[] ){
     if (hasProperty(EXTERNAL_KEY)) {
 	optCfgFile = expandHome(properties[EXTERNAL_KEY]);
 	if (!hasProperty(SPECIES_KEY))
-	// read in species from extra config file
+	// read in species and logReg parameters from extra config file
 	    readFile(optCfgFile);
     } else if (Constant::MultSpeciesMode) {
 	optCfgFile = expandHome(configPath + "cgp/log_reg_parameters_default.cfg");
@@ -479,7 +497,7 @@ void Properties::init( int argc, char* argv[] ){
 	if (name == GENEMODEL_KEY || name == NONCODING_KEY || name == SINGLESTRAND_KEY ||
 	    name == SPECIES_KEY || name == CFGPATH_KEY ||
 	    name == EXTERNAL_KEY || name == ALN_KEY ||
-	    name == TREE_KEY || name == DB_KEY || name == SEQ_KEY || name == CODONALN_KEY)
+	    name == TREE_KEY || name == DB_KEY || name == SEQ_KEY || name == CODONALN_KEY || name == REF_EXON_KEY)
 	    continue;
 	if (pos == string::npos)
 	    throw PropertiesError(string("'=' missing for parameter: ") + name);
