@@ -100,7 +100,15 @@ bool inCRFTraining = false;
 bool Constant::dbhints = false;
 // scores from logistic regression                                                                                                  
 bool Constant::logreg;
-// features are explaned in the default config file config/cgp/log_reg_parameters_default.cfg
+string Constant::referenceFile;
+string Constant::refSpecies;
+double Constant::GD_stepsize = 0.01; // stepsize of gradient descent algorithm 
+bool Constant::rLogReg = false; // for robust logistic regression
+double Constant::label_flip_prob = 0.01; // probability of a reference label to be wrong (robust logistic regression) 
+double Constant::lambda = 0; // parameter used in softmax function for exon boundary feature
+#ifdef COMPGENEPRED
+unordered_map<string, pair<int, vector<double> > > Constant::logReg_feature;
+#endif
 vector<double>Constant::ex_sc;
 vector<double>Constant::in_sc;
 vector<double>Constant::lg_es;
@@ -108,6 +116,7 @@ int Constant::oeExtensionWidth;
 bool Constant::computeNumSubs; // cumpute number of substitutions in OE
 bool Constant::useAArates;
 bool Constant::useNonCodingModel;
+bool Constant::rescaleBoni = true;
 // moved here from hints.cc
 const int power2id[31] = {1,2,4,8,16,32,64,128,
 			   256,512,1024,2048,4096,8192,16384,32768,
@@ -330,10 +339,16 @@ void Constant::init(){
     
     // scores for logistic regression
     try {
-	logreg = Properties::getBoolProperty("/CompPred/logreg");
+        logreg = Properties::getBoolProperty("/CompPred/logreg");
     } catch (...) {
-	logreg = true;
+        logreg = true;
     }
+    try {
+        lambda = Properties::getdoubleProperty("/CompPred/lambda");
+    } catch (...) {
+        lambda = 1;
+    }
+
     for(int i=0; i<17; i++){
 	try {
 	    ex_sc.push_back(Properties::getdoubleProperty("/CompPred/exon_score" + itoa(i) ));
@@ -349,19 +364,19 @@ void Constant::init(){
 	}
     }
     for(int i=0; i<4; i++){
-	try {
-	    lg_es.push_back(Properties::getdoubleProperty("lg_exon_score" + itoa(i) ));
-	} catch (...) {
-	    lg_es.push_back(0);
-	}
+      try {
+	lg_es.push_back(Properties::getdoubleProperty("lg_exon_score" + itoa(i) ));
+      } catch (...) {
+	lg_es.push_back(0);
+      }
     }
-
+    
     try {
       oeExtensionWidth = Properties::getIntProperty("/CompPred/oeExtensionWidth");
     } catch (...) {
       oeExtensionWidth = 30;
     }
-
+    
     try {
       computeNumSubs = Properties::getBoolProperty("/CompPred/computeNumSubs");
     } catch (...) {
@@ -380,6 +395,11 @@ void Constant::init(){
       useNonCodingModel = false;
     }
 
+    try {
+      rescaleBoni =  Properties::getBoolProperty("rescaleBoni");
+    } catch(...){
+      rescaleBoni = true;
+    }
 
 
     Properties::assignProperty("/UtrModel/d_polyasig_cleavage", d_polyasig_cleavage);
@@ -501,7 +521,7 @@ int quantile(const vector<int> &v, float q){
 }                                                                                                                                                                                                                                                                                        
  
 
-map<string, size_t> *getMap (vector<string> names) throw(ProjectError) {
+map<string, size_t> *getMap (vector<string> names){
     map<string, size_t> *hashtable = new map<string, size_t>;
     for (size_t i=0; i<names.size(); i++){
 	if (hashtable->find(names[i]) != hashtable->end())
